@@ -46,7 +46,10 @@ class Command(TestCommand):
                     " written. If not specified, no report is generated."),
         make_option("--coverage-exclude", action="append",
                     default=[], dest="coverage_excludes",
-                    help="Module name to exclude")
+                    help="Module name to exclude"),
+        make_option("--project-apps-tests", action="store_true",
+                    default=False, dest="project_apps_tests",
+                    help="Take tests only from project apps")
     )
 
     def __init__(self):
@@ -95,6 +98,10 @@ class Command(TestCommand):
             os.makedirs(output_dir)
 
         test_runner = TestRunner(**options)
+
+        if not test_labels and options['project_apps_tests']:
+            test_labels = getattr(settings, 'PROJECT_APPS', [])
+
         failures = test_runner.run_tests(test_labels)
 
         if failures:
@@ -143,9 +150,24 @@ class Command(TestCommand):
                 locations.append(os.path.dirname(app_config.module.__file__))
         except ImportError:
             # django 1.6
-            from django.db.models import get_app
+            from django.utils.importlib import import_module
+
+            def get_containing_app(object_name):
+                candidates = []
+                for app_label in settings.INSTALLED_APPS:
+                    if object_name.startswith(app_label):
+                        subpath = object_name[len(app_label):]
+                        if subpath == '' or subpath[0] == '.':
+                            candidates.append(app_label)
+                if candidates:
+                    return sorted(candidates, key=lambda label: -len(label))[0]
+
             for test_label in test_labels:
-                models_module = get_app(test_label.split('.')[-1])
-                locations.append(os.path.dirname(models_module.__file__))
+                app_label = get_containing_app(test_label)
+                if app_label is not None:
+                    app_module = import_module(app_label)
+                    locations.append(os.path.dirname(app_module.__file__))
+                else:
+                    warnings.warn('No app found for test: {0}'.format(test_label))
 
         return locations
